@@ -1,5 +1,3 @@
-from __future__ import print_function
-
 import argparse
 import re
 from typing import AbstractSet
@@ -10,8 +8,10 @@ from pre_commit_hooks.util import CalledProcessError
 from pre_commit_hooks.util import cmd_output
 
 
-def is_on_branch(protected, patterns=frozenset()):
-    # type: (AbstractSet[str], AbstractSet[str]) -> bool
+def is_on_branch(
+        protected: AbstractSet[str],
+        patterns: AbstractSet[str] = frozenset(),
+) -> bool:
     try:
         ref_name = cmd_output('git', 'symbolic-ref', 'HEAD')
     except CalledProcessError:
@@ -23,7 +23,7 @@ def is_on_branch(protected, patterns=frozenset()):
     )
 
 
-def main(argv=None):  # type: (Optional[Sequence[str]]) -> int
+def main(argv: Optional[Sequence[str]] = None) -> int:
     parser = argparse.ArgumentParser()
     parser.add_argument(
         '-b', '--branch', action='append',
